@@ -493,10 +493,32 @@ fluidRow(
  column(7,
     tabsetPanel(id='plottabs',
       tabPanel('Network Plot', br(),
-                plotOutput('nwplot')
+                plotOutput('nwplot', click = "plot_click",
+                           dblclick = dblclickOpts(id = "plot_dblclick"),
+                           hover = hoverOpts(id = "plot_hover", delay = 100,
+                                             delayType = "throttle"),
+                           brush = brushOpts(id = "plot_brush")
+                           )
         ),
       tabPanel('Attributes', br(),
-              dataTableOutput("attrtbl")
+               conditionalPanel('input.attrview == "Large table"',
+                                dataTableOutput("attrtbl_lg")
+                                ),
+               conditionalPanel('input.attrview == "Small tables"',
+                                verbatimTextOutput("attrtbl_sm")
+                                ),
+               conditionalPanel('input.attrview == "Plot summaries"',
+                                tags$label("Type of plots"),
+                                helpText("Density plots will only be created for",
+                                         "numeric attributes with more than nine",
+                                         "levels."),
+                                selectInput("attrhistaxis",
+                                            label = NULL,
+                                            choices = c("Barplot: counts" = "count",
+                                                        "Barplot: percents" = "percent",
+                                                        "Density plot" = "density")),
+                                uiOutput("attrhistplotspace"))
+
                ),
       tabPanel('Degree Distribution',
                p(class='helper', id='ddhelper', icon('question-circle')),
@@ -519,7 +541,7 @@ fluidRow(
                plotOutput('geodistplot')
                ),
       tabPanel('More', value='More', br(),
-               h5('Conditional uniform graph tests', icon('angle-double-left'),
+               h5('Null model tests', icon('angle-double-left'),
                   id="cugtitle"),
                wellPanel(id="cugbox",
                  column(4, uiOutput("dynamiccugterm")),
@@ -712,6 +734,8 @@ fluidRow(
        tabPanel(title='Display Options', br(),
           wellPanel(
                 conditionalPanel(condition='input.plottabs == "Network Plot"',
+                   selectInput('activeplot', label = NULL,
+                               choices = c("Static Plot", "Interactive Plot")),
                    checkboxInput('iso',
                                  label = 'Display isolates',
                                  value = TRUE),
@@ -740,6 +764,11 @@ fluidRow(
                    downloadButton('nwplotdownload',
                                   label = "Download Plot", class = "btn-sm")),
                 conditionalPanel(condition='input.plottabs == "Attributes"',
+                                 selectInput("attrview", label = "View attributes in:",
+                                             choices = c("Large table",
+                                                         "Small tables",
+                                                         "Plot summaries")),
+                                 br(),
                                  uiOutput("attrcheck")
                 ),
                 conditionalPanel(condition='input.plottabs == "Degree Distribution"',
@@ -877,7 +906,7 @@ actionLink('plotright', icon=icon('arrow-right', class='fa-2x'), label=NULL)
                       fluidRow(
                         column(12,
                                a("Commonly used ergm terms",
-                                 href = "http://statnet.csde.washington.edu/EpiModel/nme/d2-ergmterms.html",
+                                 href = "http://statnet.github.io/nme/ergmterms.html",
                                  target = "_blank"), br(),
                                a("Term cross-reference tables",
                                  href = "http://cran.r-project.org/web/packages/ergm/vignettes/ergm-term-crossRef.html",
@@ -894,7 +923,7 @@ actionLink('plotright', icon=icon('arrow-right', class='fa-2x'), label=NULL)
                       fluidRow(
                         column(12,
                                div(id="termdocbox",
-                                    verbatimTextOutput("termdoc")
+                                    uiOutput("termdoc")
                                 ),
                                 div(id = "termexpand",
                                     icon(name = "angle-double-up"))
@@ -909,12 +938,13 @@ actionLink('plotright', icon=icon('arrow-right', class='fa-2x'), label=NULL)
                     fluidRow(class = "shiftright",
                       column(3, style = "padding-left: 0;",
                         inlineSelectInput('controltype',label = NULL,
-                                          choices = c("MCMC","MCMLE"),
+                                          choices = c("MCMC"),
                                           style="margin:10px 0px;")),
                       column(5,
                         checkboxInput('controldefault', 'Use default options', value = TRUE))
                     ),
-                        conditionalPanel(condition = "input.controltype == 'MCMC'", class = "shiftright",
+                        conditionalPanel(condition = "input.controltype == 'MCMC'",
+                                         class = "shiftright gray", id = "mcmcopt1",
                           fluidRow(
                             column(4,
                                    span("Interval:"),
@@ -1082,9 +1112,11 @@ tabPanel(title='Goodness of Fit',value='tab6',
                   verbatimTextOutput('checkterms_gof'))
           ),
          p('If you do not specify a term the default formula for undirected
-           networks is ', code('~ degree + espartners + distance'), 'and for
+           networks is ', code('~ degree + espartners + distance + model'), 'and for
            directed networks is ', code('~ idegree + odegree + espartners +
-                                        distance'), '.'),
+                                        distance + model'), '.  ',
+           'The "model" plot shows how well the fitted model reproduces the observed values for the 
+           terms in the model (the sufficient statistics), and can be used to assess convergence.'),
          fluidRow(
             column(2,
                    p("Goodness of fit term:"),
@@ -1157,7 +1189,8 @@ tabPanel(title='Simulations', value='tab7',
                              column(7,
                                     checkboxInput('simcontroldefault','Use default options', value=TRUE))
                            ),
-                           conditionalPanel(condition="input.simcontroltype == 'MCMC'", class="shiftright",
+                           conditionalPanel(condition="input.simcontroltype == 'MCMC'",
+                                            class="shiftright gray", id = "mcmcopt2",
                              fluidRow(
                                     column(5,
                                         span("Interval:"),
